import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * auth block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#auth Service#auth}
     *
     * @stability stable
     */
    readonly auth?: ServiceAuth[];
    /**
     * converge_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#converge_config Service#converge_config}
     *
     * @stability stable
     */
    readonly convergeConfig?: ServiceConvergeConfig[];
    /**
     * endpoint_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#endpoint_spec Service#endpoint_spec}
     *
     * @stability stable
     */
    readonly endpointSpec?: ServiceEndpointSpec[];
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceLabels[];
    /**
     * mode block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: ServiceMode[];
    /**
     * rollback_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#rollback_config Service#rollback_config}
     *
     * @stability stable
     */
    readonly rollbackConfig?: ServiceRollbackConfig[];
    /**
     * task_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#task_spec Service#task_spec}
     *
     * @stability stable
     */
    readonly taskSpec: ServiceTaskSpec[];
    /**
     * update_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#update_config Service#update_config}
     *
     * @stability stable
     */
    readonly updateConfig?: ServiceUpdateConfig[];
}
/**
 * @stability stable
 */
export interface ServiceAuth {
    /**
     * The password.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#password Service#password}
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * The address of the server for the authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#server_address Service#server_address}
     *
     * @stability stable
     */
    readonly serverAddress: string;
    /**
     * The username.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#username Service#username}
     *
     * @stability stable
     */
    readonly username?: string;
}
/**
 * @stability stable
 */
export interface ServiceConvergeConfig {
    /**
     * The interval to check if the desired state is reached (ms|s). Defaults to `7s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * The timeout of the service to reach the desired state (s|m). Defaults to `3m`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#timeout Service#timeout}
     *
     * @stability stable
     */
    readonly timeout?: string;
}
/**
 * @stability stable
 */
export interface ServiceEndpointSpecPorts {
    /**
     * A random name for the port.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * Rrepresents the protocol of a port: 'tcp', 'udp' or 'sctp'. Defaults to `tcp`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#protocol Service#protocol}
     *
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * Represents the mode in which the port is to be published: 'ingress' or 'host'. Defaults to `ingress`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#publish_mode Service#publish_mode}
     *
     * @stability stable
     */
    readonly publishMode?: string;
    /**
     * The port on the swarm hosts.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#published_port Service#published_port}
     *
     * @stability stable
     */
    readonly publishedPort?: number;
    /**
     * The port inside the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#target_port Service#target_port}
     *
     * @stability stable
     */
    readonly targetPort: number;
}
/**
 * @stability stable
 */
export interface ServiceEndpointSpec {
    /**
     * The mode of resolution to use for internal load balancing between tasks.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: string;
    /**
     * ports block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#ports Service#ports}
     *
     * @stability stable
     */
    readonly ports?: ServiceEndpointSpecPorts[];
}
/**
 * @stability stable
 */
export interface ServiceLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ServiceModeReplicated {
    /**
     * The amount of replicas of the service. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#replicas Service#replicas}
     *
     * @stability stable
     */
    readonly replicas?: number;
}
/**
 * @stability stable
 */
export interface ServiceMode {
    /**
     * The global service mode. Defaults to `false`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#global Service#global}
     *
     * @stability stable
     */
    readonly global?: boolean;
    /**
     * replicated block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#replicated Service#replicated}
     *
     * @stability stable
     */
    readonly replicated?: ServiceModeReplicated[];
}
/**
 * @stability stable
 */
export interface ServiceRollbackConfig {
    /**
     * Delay between task rollbacks (ns|us|ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Action on rollback failure: pause | continue. Defaults to `pause`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#failure_action Service#failure_action}
     *
     * @stability stable
     */
    readonly failureAction?: string;
    /**
     * Failure rate to tolerate during a rollback. Defaults to `0.0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_failure_ratio Service#max_failure_ratio}
     *
     * @stability stable
     */
    readonly maxFailureRatio?: string;
    /**
     * Duration after each task rollback to monitor for failure (ns|us|ms|s|m|h). Defaults to `5s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#monitor Service#monitor}
     *
     * @stability stable
     */
    readonly monitor?: string;
    /**
     * Rollback order: either 'stop-first' or 'start-first'. Defaults to `stop-first`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#order Service#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * Maximum number of tasks to be rollbacked in one iteration. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#parallelism Service#parallelism}
     *
     * @stability stable
     */
    readonly parallelism?: number;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecConfigs {
    /**
     * ID of the specific config that we're referencing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#config_id Service#config_id}
     *
     * @stability stable
     */
    readonly configId: string;
    /**
     * Name of the config that this references, but this is just provided for lookup/display purposes.
     *
     * The config in the reference will be identified by its ID
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#config_name Service#config_name}
     *
     * @stability stable
     */
    readonly configName?: string;
    /**
     * Represents the file GID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_gid Service#file_gid}
     *
     * @stability stable
     */
    readonly fileGid?: string;
    /**
     * Represents represents the FileMode of the file. Defaults to `0o444`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_mode Service#file_mode}
     *
     * @stability stable
     */
    readonly fileMode?: number;
    /**
     * Represents the final filename in the filesystem.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_name Service#file_name}
     *
     * @stability stable
     */
    readonly fileName: string;
    /**
     * Represents the file UID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_uid Service#file_uid}
     *
     * @stability stable
     */
    readonly fileUid?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecDnsConfig {
    /**
     * The IP addresses of the name servers.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nameservers Service#nameservers}
     *
     * @stability stable
     */
    readonly nameservers: string[];
    /**
     * A list of internal resolver variables to be modified (e.g., debug, ndots:3, etc.).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#options Service#options}
     *
     * @stability stable
     */
    readonly options?: string[];
    /**
     * A search list for host-name lookup.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#search Service#search}
     *
     * @stability stable
     */
    readonly search?: string[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecHealthcheck {
    /**
     * Time between running the check (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#interval Service#interval}
     *
     * @stability stable
     */
    readonly interval?: string;
    /**
     * Consecutive failures needed to report unhealthy. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#retries Service#retries}
     *
     * @stability stable
     */
    readonly retries?: number;
    /**
     * Start period for the container to initialize before counting retries towards unstable (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#start_period Service#start_period}
     *
     * @stability stable
     */
    readonly startPeriod?: string;
    /**
     * The test to perform as list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#test Service#test}
     *
     * @stability stable
     */
    readonly test: string[];
    /**
     * Maximum time to allow one check to run (ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#timeout Service#timeout}
     *
     * @stability stable
     */
    readonly timeout?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecHosts {
    /**
     * The name of the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#host Service#host}
     *
     * @stability stable
     */
    readonly host: string;
    /**
     * The ip of the host.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#ip Service#ip}
     *
     * @stability stable
     */
    readonly ip: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsBindOptions {
    /**
     * A propagation mode with the value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#propagation Service#propagation}
     *
     * @stability stable
     */
    readonly propagation?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsTmpfsOptions {
    /**
     * The permission mode for the tmpfs mount in an integer.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mode Service#mode}
     *
     * @stability stable
     */
    readonly mode?: number;
    /**
     * The size for the tmpfs mount in bytes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#size_bytes Service#size_bytes}
     *
     * @stability stable
     */
    readonly sizeBytes?: number;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels {
    /**
     * Name of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#label Service#label}
     *
     * @stability stable
     */
    readonly label: string;
    /**
     * Value of the label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#value Service#value}
     *
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMountsVolumeOptions {
    /**
     * Name of the driver to use to create the volume.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#driver_name Service#driver_name}
     *
     * @stability stable
     */
    readonly driverName?: string;
    /**
     * key/value map of driver specific options.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#driver_options Service#driver_options}
     *
     * @stability stable
     */
    readonly driverOptions?: {
        [key: string]: string;
    };
    /**
     * Populate volume with data from the target.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#no_copy Service#no_copy}
     *
     * @stability stable
     */
    readonly noCopy?: boolean;
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceTaskSpecContainerSpecMountsVolumeOptionsLabels[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecMounts {
    /**
     * Whether the mount should be read-only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#read_only Service#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Mount source (e.g. a volume name, a host path).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#source Service#source}
     *
     * @stability stable
     */
    readonly source?: string;
    /**
     * Container path.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#target Service#target}
     *
     * @stability stable
     */
    readonly target: string;
    /**
     * The mount type.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#type Service#type}
     *
     * @stability stable
     */
    readonly type: string;
    /**
     * bind_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#bind_options Service#bind_options}
     *
     * @stability stable
     */
    readonly bindOptions?: ServiceTaskSpecContainerSpecMountsBindOptions[];
    /**
     * tmpfs_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#tmpfs_options Service#tmpfs_options}
     *
     * @stability stable
     */
    readonly tmpfsOptions?: ServiceTaskSpecContainerSpecMountsTmpfsOptions[];
    /**
     * volume_options block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#volume_options Service#volume_options}
     *
     * @stability stable
     */
    readonly volumeOptions?: ServiceTaskSpecContainerSpecMountsVolumeOptions[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivilegesCredentialSpec {
    /**
     * Load credential spec from this file.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file Service#file}
     *
     * @stability stable
     */
    readonly file?: string;
    /**
     * Load credential spec from this value in the Windows registry.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#registry Service#registry}
     *
     * @stability stable
     */
    readonly registry?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext {
    /**
     * Disable SELinux.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#disable Service#disable}
     *
     * @stability stable
     */
    readonly disable?: boolean;
    /**
     * SELinux level label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#level Service#level}
     *
     * @stability stable
     */
    readonly level?: string;
    /**
     * SELinux role label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#role Service#role}
     *
     * @stability stable
     */
    readonly role?: string;
    /**
     * SELinux type label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#type Service#type}
     *
     * @stability stable
     */
    readonly type?: string;
    /**
     * SELinux user label.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#user Service#user}
     *
     * @stability stable
     */
    readonly user?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecPrivileges {
    /**
     * credential_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#credential_spec Service#credential_spec}
     *
     * @stability stable
     */
    readonly credentialSpec?: ServiceTaskSpecContainerSpecPrivilegesCredentialSpec[];
    /**
     * se_linux_context block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#se_linux_context Service#se_linux_context}
     *
     * @stability stable
     */
    readonly seLinuxContext?: ServiceTaskSpecContainerSpecPrivilegesSeLinuxContext[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpecSecrets {
    /**
     * Represents the file GID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_gid Service#file_gid}
     *
     * @stability stable
     */
    readonly fileGid?: string;
    /**
     * Represents represents the FileMode of the file. Defaults to `0o444`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_mode Service#file_mode}
     *
     * @stability stable
     */
    readonly fileMode?: number;
    /**
     * Represents the final filename in the filesystem.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_name Service#file_name}
     *
     * @stability stable
     */
    readonly fileName: string;
    /**
     * Represents the file UID. Defaults to `0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#file_uid Service#file_uid}
     *
     * @stability stable
     */
    readonly fileUid?: string;
    /**
     * ID of the specific secret that we're referencing.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secret_id Service#secret_id}
     *
     * @stability stable
     */
    readonly secretId: string;
    /**
     * Name of the secret that this references, but this is just provided for lookup/display purposes.
     *
     * The config in the reference will be identified by its ID
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secret_name Service#secret_name}
     *
     * @stability stable
     */
    readonly secretName?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecContainerSpec {
    /**
     * Arguments to the command.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#args Service#args}
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * The command to be run in the image.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#command Service#command}
     *
     * @stability stable
     */
    readonly command?: string[];
    /**
     * The working directory for commands to run in.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#dir Service#dir}
     *
     * @stability stable
     */
    readonly dir?: string;
    /**
     * A list of environment variables in the form VAR="value".
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#env Service#env}
     *
     * @stability stable
     */
    readonly env?: {
        [key: string]: string;
    };
    /**
     * A list of additional groups that the container process will run as.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#groups Service#groups}
     *
     * @stability stable
     */
    readonly groups?: string[];
    /**
     * The hostname to use for the container, as a valid RFC 1123 hostname.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#hostname Service#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * The image name to use for the containers of the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#image Service#image}
     *
     * @stability stable
     */
    readonly image: string;
    /**
     * Isolation technology of the containers running the service. (Windows only). Defaults to `default`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#isolation Service#isolation}
     *
     * @stability stable
     */
    readonly isolation?: string;
    /**
     * Mount the container's root filesystem as read only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#read_only Service#read_only}
     *
     * @stability stable
     */
    readonly readOnly?: boolean;
    /**
     * Amount of time to wait for the container to terminate before forcefully removing it (ms|s|m|h).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#stop_grace_period Service#stop_grace_period}
     *
     * @stability stable
     */
    readonly stopGracePeriod?: string;
    /**
     * Signal to stop the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#stop_signal Service#stop_signal}
     *
     * @stability stable
     */
    readonly stopSignal?: string;
    /**
     * The user inside the container.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#user Service#user}
     *
     * @stability stable
     */
    readonly user?: string;
    /**
     * configs block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#configs Service#configs}
     *
     * @stability stable
     */
    readonly configs?: ServiceTaskSpecContainerSpecConfigs[];
    /**
     * dns_config block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#dns_config Service#dns_config}
     *
     * @stability stable
     */
    readonly dnsConfig?: ServiceTaskSpecContainerSpecDnsConfig[];
    /**
     * healthcheck block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#healthcheck Service#healthcheck}
     *
     * @stability stable
     */
    readonly healthcheck?: ServiceTaskSpecContainerSpecHealthcheck[];
    /**
     * hosts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#hosts Service#hosts}
     *
     * @stability stable
     */
    readonly hosts?: ServiceTaskSpecContainerSpecHosts[];
    /**
     * labels block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#labels Service#labels}
     *
     * @stability stable
     */
    readonly labels?: ServiceTaskSpecContainerSpecLabels[];
    /**
     * mounts block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#mounts Service#mounts}
     *
     * @stability stable
     */
    readonly mounts?: ServiceTaskSpecContainerSpecMounts[];
    /**
     * privileges block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#privileges Service#privileges}
     *
     * @stability stable
     */
    readonly privileges?: ServiceTaskSpecContainerSpecPrivileges[];
    /**
     * secrets block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#secrets Service#secrets}
     *
     * @stability stable
     */
    readonly secrets?: ServiceTaskSpecContainerSpecSecrets[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecLogDriver {
    /**
     * The logging driver to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#name Service#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The options for the logging driver.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#options Service#options}
     *
     * @stability stable
     */
    readonly options?: {
        [key: string]: string;
    };
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecPlacementPlatforms {
    /**
     * The architecture, e.g. `amd64`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#architecture Service#architecture}
     *
     * @stability stable
     */
    readonly architecture: string;
    /**
     * The operation system, e.g. `linux`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#os Service#os}
     *
     * @stability stable
     */
    readonly os: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecPlacement {
    /**
     * An array of constraints. e.g.: `node.role==manager`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#constraints Service#constraints}
     *
     * @stability stable
     */
    readonly constraints?: string[];
    /**
     * Maximum number of replicas for per node (default value is `0`, which is unlimited).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_replicas Service#max_replicas}
     *
     * @stability stable
     */
    readonly maxReplicas?: number;
    /**
     * Preferences provide a way to make the scheduler aware of factors such as topology.
     *
     * They are provided in order from highest to lowest precedence, e.g.: spread=node.role.manager
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#prefs Service#prefs}
     *
     * @stability stable
     */
    readonly prefs?: string[];
    /**
     * platforms block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#platforms Service#platforms}
     *
     * @stability stable
     */
    readonly platforms?: ServiceTaskSpecPlacementPlatforms[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesLimits {
    /**
     * The amounf of memory in bytes the container allocates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#memory_bytes Service#memory_bytes}
     *
     * @stability stable
     */
    readonly memoryBytes?: number;
    /**
     * CPU shares in units of `1/1e9` (or `10^-9`) of the CPU. Should be at least 1000000.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nano_cpus Service#nano_cpus}
     *
     * @stability stable
     */
    readonly nanoCpus?: number;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesReservationGenericResources {
    /**
     * The Integer resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#discrete_resources_spec Service#discrete_resources_spec}
     *
     * @stability stable
     */
    readonly discreteResourcesSpec?: string[];
    /**
     * The String resources.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#named_resources_spec Service#named_resources_spec}
     *
     * @stability stable
     */
    readonly namedResourcesSpec?: string[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResourcesReservation {
    /**
     * The amounf of memory in bytes the container allocates.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#memory_bytes Service#memory_bytes}
     *
     * @stability stable
     */
    readonly memoryBytes?: number;
    /**
     * CPU shares in units of 1/1e9 (or 10^-9) of the CPU. Should be at least 1000000.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#nano_cpus Service#nano_cpus}
     *
     * @stability stable
     */
    readonly nanoCpus?: number;
    /**
     * generic_resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#generic_resources Service#generic_resources}
     *
     * @stability stable
     */
    readonly genericResources?: ServiceTaskSpecResourcesReservationGenericResources[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecResources {
    /**
     * limits block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#limits Service#limits}
     *
     * @stability stable
     */
    readonly limits?: ServiceTaskSpecResourcesLimits[];
    /**
     * reservation block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#reservation Service#reservation}
     *
     * @stability stable
     */
    readonly reservation?: ServiceTaskSpecResourcesReservation[];
}
/**
 * @stability stable
 */
export interface ServiceTaskSpecRestartPolicy {
    /**
     * Condition for restart.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#condition Service#condition}
     *
     * @stability stable
     */
    readonly condition?: string;
    /**
     * Delay between restart attempts (ms|s|m|h).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Maximum attempts to restart a given container before giving up (default value is `0`, which is ignored).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_attempts Service#max_attempts}
     *
     * @stability stable
     */
    readonly maxAttempts?: number;
    /**
     * The time window used to evaluate the restart policy (default value is `0`, which is unbounded) (ms|s|m|h).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#window Service#window}
     *
     * @stability stable
     */
    readonly window?: string;
}
/**
 * @stability stable
 */
export interface ServiceTaskSpec {
    /**
     * A counter that triggers an update even if no relevant parameters have been changed. See the [spec](https://github.com/docker/swarmkit/blob/master/api/specs.proto#L126).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#force_update Service#force_update}
     *
     * @stability stable
     */
    readonly forceUpdate?: number;
    /**
     * Ids of the networks in which the  container will be put in.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#networks Service#networks}
     *
     * @stability stable
     */
    readonly networks?: string[];
    /**
     * Runtime is the type of runtime specified for the task executor. See the [types](https://github.com/moby/moby/blob/master/api/types/swarm/runtime.go).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#runtime Service#runtime}
     *
     * @stability stable
     */
    readonly runtime?: string;
    /**
     * container_spec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#container_spec Service#container_spec}
     *
     * @stability stable
     */
    readonly containerSpec: ServiceTaskSpecContainerSpec[];
    /**
     * log_driver block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#log_driver Service#log_driver}
     *
     * @stability stable
     */
    readonly logDriver?: ServiceTaskSpecLogDriver[];
    /**
     * placement block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#placement Service#placement}
     *
     * @stability stable
     */
    readonly placement?: ServiceTaskSpecPlacement[];
    /**
     * resources block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#resources Service#resources}
     *
     * @stability stable
     */
    readonly resources?: ServiceTaskSpecResources[];
    /**
     * restart_policy block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#restart_policy Service#restart_policy}
     *
     * @stability stable
     */
    readonly restartPolicy?: ServiceTaskSpecRestartPolicy[];
}
/**
 * @stability stable
 */
export interface ServiceUpdateConfig {
    /**
     * Delay between task updates (ns|us|ms|s|m|h). Defaults to `0s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#delay Service#delay}
     *
     * @stability stable
     */
    readonly delay?: string;
    /**
     * Action on update failure: pause | continue | rollback. Defaults to `pause`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#failure_action Service#failure_action}
     *
     * @stability stable
     */
    readonly failureAction?: string;
    /**
     * Failure rate to tolerate during an update. Defaults to `0.0`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#max_failure_ratio Service#max_failure_ratio}
     *
     * @stability stable
     */
    readonly maxFailureRatio?: string;
    /**
     * Duration after each task update to monitor for failure (ns|us|ms|s|m|h). Defaults to `5s`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#monitor Service#monitor}
     *
     * @stability stable
     */
    readonly monitor?: string;
    /**
     * Update order: either 'stop-first' or 'start-first'. Defaults to `stop-first`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#order Service#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * Maximum number of tasks to be updated in one iteration. Defaults to `1`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/docker/r/service.html#parallelism Service#parallelism}
     *
     * @stability stable
     */
    readonly parallelism?: number;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/docker/r/service.html docker_service}.
 *
 * @stability stable
 */
export declare class Service extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/docker/r/service.html docker_service} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ServiceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _auth?;
    /**
     * @stability stable
     */
    get auth(): ServiceAuth[];
    /**
     * @stability stable
     */
    set auth(value: ServiceAuth[]);
    /**
     * @stability stable
     */
    resetAuth(): void;
    /**
     * @stability stable
     */
    get authInput(): ServiceAuth[] | undefined;
    private _convergeConfig?;
    /**
     * @stability stable
     */
    get convergeConfig(): ServiceConvergeConfig[];
    /**
     * @stability stable
     */
    set convergeConfig(value: ServiceConvergeConfig[]);
    /**
     * @stability stable
     */
    resetConvergeConfig(): void;
    /**
     * @stability stable
     */
    get convergeConfigInput(): ServiceConvergeConfig[] | undefined;
    private _endpointSpec?;
    /**
     * @stability stable
     */
    get endpointSpec(): ServiceEndpointSpec[];
    /**
     * @stability stable
     */
    set endpointSpec(value: ServiceEndpointSpec[]);
    /**
     * @stability stable
     */
    resetEndpointSpec(): void;
    /**
     * @stability stable
     */
    get endpointSpecInput(): ServiceEndpointSpec[] | undefined;
    private _labels?;
    /**
     * @stability stable
     */
    get labels(): ServiceLabels[];
    /**
     * @stability stable
     */
    set labels(value: ServiceLabels[]);
    /**
     * @stability stable
     */
    resetLabels(): void;
    /**
     * @stability stable
     */
    get labelsInput(): ServiceLabels[] | undefined;
    private _mode?;
    /**
     * @stability stable
     */
    get mode(): ServiceMode[];
    /**
     * @stability stable
     */
    set mode(value: ServiceMode[]);
    /**
     * @stability stable
     */
    resetMode(): void;
    /**
     * @stability stable
     */
    get modeInput(): ServiceMode[] | undefined;
    private _rollbackConfig?;
    /**
     * @stability stable
     */
    get rollbackConfig(): ServiceRollbackConfig[];
    /**
     * @stability stable
     */
    set rollbackConfig(value: ServiceRollbackConfig[]);
    /**
     * @stability stable
     */
    resetRollbackConfig(): void;
    /**
     * @stability stable
     */
    get rollbackConfigInput(): ServiceRollbackConfig[] | undefined;
    private _taskSpec;
    /**
     * @stability stable
     */
    get taskSpec(): ServiceTaskSpec[];
    /**
     * @stability stable
     */
    set taskSpec(value: ServiceTaskSpec[]);
    /**
     * @stability stable
     */
    get taskSpecInput(): ServiceTaskSpec[];
    private _updateConfig?;
    /**
     * @stability stable
     */
    get updateConfig(): ServiceUpdateConfig[];
    /**
     * @stability stable
     */
    set updateConfig(value: ServiceUpdateConfig[]);
    /**
     * @stability stable
     */
    resetUpdateConfig(): void;
    /**
     * @stability stable
     */
    get updateConfigInput(): ServiceUpdateConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
